@@ -3,6 +3,8 @@ package t::lib::TestApp;
 use Dancer;
 use Dancer::Plugin::EscapeHTML;
 
+use Foo;
+
 setting 'template' => 'Simple';
 setting 'show_errors' => 1;
 
@@ -18,4 +20,9 @@ get '/excluded' => sub {
     return template 'excluded', { foo_html => "<p>Foo</p>" };
 };
 
+get '/object' => sub {
+    my $obj = Foo->new();
+    return template 'object', { foo => $obj };
+};
+
 1;
